@@ -44,7 +44,9 @@
 #define XtNrightAuxBeadColor ((char *) "rightAuxBeadColor")
 #define XtNsecondaryBeadColor ((char *) "secondaryBeadColor")
 #define XtNhighlightBeadColor ((char *) "highlightBeadColor")
-#define XtNcheckerBeadColor ((char *) "checkerBeadColor")
+#define XtNprimaryMarkerColor ((char *) "primaryMarkerColor")
+#define XtNleftAuxMarkerColor ((char *) "leftAuxMarkerColor")
+#define XtNrightAuxMarkerColor ((char *) "rightAuxMarkerColor")
 #define XtNprimaryRailColor ((char *) "primaryRailColor")
 #define XtNsecondaryRailColor ((char *) "secondaryRailColor")
 #define XtNhighlightRailColor ((char *) "highlightRailColor")
@@ -104,13 +106,16 @@
 #define XtNdisplayBase ((char *) "displayBase")
 #define XtNpressOffset ((char *) "pressOffset")
 #define XtNromanNumerals ((char *) "romanNumerals")
+#define XtNromanNumeralsMode ((char *) "romanNumeralsMode")
 #define XtNlatin ((char *) "latin")
-#define XtNancientRoman ((char *) "ancientRoman")
-#define XtNmodernRoman ((char *) "modernRoman")
+#define XtNromanMarkers ((char *) "romanMarkers")
+#define XtNromanMarkersMode ((char *) "romanMarkersMode")
+#define XtNsubdecksSeparated ((char *) "subdecksSeparated")
+#define XtNaltSubbeadPlacement ((char *) "altSubbeadPlacement")
 #define XtNmode ((char *) "mode")
 #define XtNformat ((char *) "format")
-#define XtNsubmode ((char *) "submode")
 #define XtNmuseum ((char *) "museum")
+#define XtNmuseumMode ((char *) "museumMode")
 #define XtNversionOnly ((char *) "versionOnly")
 #define XtNmenu ((char *) "menu")
 #define XtNdeck ((char *) "deck")
@@ -188,13 +193,16 @@
 #define XtCDisplayBase ((char *) "DisplayBase")
 #define XtCPressOffset ((char *) "PressOffset")
 #define XtCRomanNumerals ((char *) "RomanNumerals")
+#define XtCRomanNumeralsMode ((char *) "RomanNumeralsMode")
 #define XtCLatin ((char *) "Latin")
-#define XtCAncientRoman ((char *) "AncientRoman")
-#define XtCModernRoman ((char *) "ModernRoman")
+#define XtCRomanMarkers ((char *) "RomanMarkers")
+#define XtCRomanMarkersMode ((char *) "RomanMarkersMode")
 #define XtCMode ((char *) "Mode")
 #define XtCFormat ((char *) "Format")
-#define XtCSubmode ((char *) "Submode")
+#define XtCSubdecksSeparated ((char *) "SubdecksSeparated")
+#define XtCAltSubbeadPlacement ((char *) "AltSubbeadPlacement")
 #define XtCMuseum ((char *) "Museum")
+#define XtCMuseumMode ((char *) "MuseumMode")
 #define XtCMenu ((char *) "Menu")
 #define XtCDeck ((char *) "Deck")
 #define XtCRail ((char *) "Rail")
@@ -220,6 +228,9 @@ typedef struct {
 } abacusCallbackStruct;
 #endif
 
+extern const char *museumChoices[];
+extern const char *romanFormatChoices[];
+
 #define ACTION_EXIT 100
 #define ACTION_HIDE 101
 #define ACTION_BASE_DEFAULT 102
@@ -242,18 +253,19 @@ typedef struct {
 #define ACTION_DECREMENT 211
 #define ACTION_FORMAT 220
 #define ACTION_ROMAN_NUMERALS 230
-#define ACTION_ANCIENT_ROMAN 231
 #define ACTION_LATIN 232
 #define ACTION_GROUP 233
 #define ACTION_PLACE_ON_RAIL 234
 #define ACTION_SIGN 240
 #define ACTION_QUARTER 241
-#define ACTION_QUARTER_PERCENT 242
-#define ACTION_TWELFTH 243
-#define ACTION_SUBDECK 250
-#define ACTION_EIGHTH 251
-#define ACTION_MUSEUM 252
-#define ACTION_MODERN_ROMAN 260
+#define ACTION_TWELFTH 242
+#define ACTION_QUARTER_PERCENT 250
+#define ACTION_SUBDECK 251
+#define ACTION_EIGHTH 252
+#define ACTION_MUSEUM 253
+#define ACTION_ROMAN_MARKERS 254
+#define ACTION_SUBDECKS_SEPARATED 255
+#define ACTION_ALT_SUBBEAD_PLACEMENT 256
 #define ACTION_ANOMALY 261
 #define ACTION_WATCH 262
 #define ACTION_VERTICAL 263
@@ -361,9 +373,18 @@ typedef struct {
 #define GENERIC 7
 #define MAX_FORMATS 7
 #define MAX_MODES 8
+#define NONE 0
+#define ANCIENT 1
+#define MODERN 2
+#define LATE 3
+#define ALT 4
+#define ROMAN_MARKERS_FORMATS 5
+#define ROMAN_NUMERALS_FORMATS 3
 #define TEACH_STRING0 "Enter calculation X+Y, X-Y, X*Y, X/Y, Xv, or Xu where X and result nonnegative."
 #define TEACH_STRING1 "Press enter to go through calculation steps."
 #define ZERO_STRING "0.0"
+#define COUNTRY_SIZE 3
+#define ROMAN_FORMAT_SIZE 8
 
 typedef struct _AbacusRec *AbacusWidget;
 typedef struct _AbacusRec *AbacusDemoWidget;
