@@ -43,7 +43,7 @@ static void selectAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nAr
 static void clearAbacusDemo(AbacusWidget w);
 static void toggleDemoAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nArgs);
 static void showNextAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nArgs);
-static void showRepeatAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nArgs);
+static void showEnterAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nArgs);
 static void showJumpAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nArgs);
 static void showMoreAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nArgs);
 static void incAbacusDemo(AbacusWidget w, XEvent *event, char **args, int nArgs);
@@ -67,11 +67,12 @@ static char translationsDemo[] =
  <KeyPress>c: Select()\n\
  <KeyPress>o: Demo()\n\
  <KeyPress>n: Next()\n\
- <KeyPress>r: Repeat()\n\
+ <KeyPress>Tab: Next()\n\
+ <KeyPress>e: Enter()\n\
+ <KeyPress>Return: Enter()\n\
  <KeyPress>j: Jump()\n\
  <KeyPress>0x20: More()\n\
  <KeyPress>KP_Space: More()\n\
- <KeyPress>Return: More()\n\
  <KeyPress>1: IncChapter()\n\
  <KeyPress>2: DecChapter()\n\
  <KeyPress>3: AddChapter()\n\
@@ -95,7 +96,7 @@ static XtActionsRec actionsListDemo[] =
 	{(char *) "Select", (XtActionProc) selectAbacusDemo},
 	{(char *) "Demo", (XtActionProc) toggleDemoAbacusDemo},
 	{(char *) "Next", (XtActionProc) showNextAbacusDemo},
-	{(char *) "Repeat", (XtActionProc) showRepeatAbacusDemo},
+	{(char *) "Enter", (XtActionProc) showEnterAbacusDemo},
 	{(char *) "Jump", (XtActionProc) showJumpAbacusDemo},
 	{(char *) "More", (XtActionProc) showMoreAbacusDemo},
 	{(char *) "IncChapter", (XtActionProc) incAbacusDemo},
@@ -321,25 +322,25 @@ static const char *introFramedText[LINES] =
 static const char *bookText[LINES] =
 {
 	"  ",
-	"Type: `r' to Read this book",
-	"      `n' to Next book",
-	"      `q' to Quit the demo",
+	READ_BOOK,
+	NEXT_BOOK,
+	QUIT,
 };
 
 static const char *chapterText[LINES] =
 {
 	"     ",
-	"Type: `r' to Read this chapter",
-	"      `n' to Next chapter",
-	"      `q' to Quit the demo",
+	READ_CHAPTER,
+	NEXT_CHAPTER,
+	QUIT,
 };
 
-static const char *queryText[LINES] =
+static const char *lessonText[LINES] =
 {
-	"Type: `n' for the Next lesson",
-	"      `r' to Repeat previous lesson",
-	"      `j' to Jump to next chapter",
-	"      `q' to Quit the demo",
+	NEXT_LESSON,
+	READ_LESSON,
+	JUMP_LESSON,
+	QUIT,
 };
 
 static const char *conclLesson[LINES] =
@@ -430,7 +431,7 @@ static unsigned int getEdition(AbacusWidget w) {
 		return CHINESE;
 	}
 #ifdef DEBUG
-	(void) fprintf(stderr, " getEdition returning : %d\n", edition);
+	(void) fprintf(stderr, " getEdition version : %d\n", edition);
 #endif
 	return edition;
 }
@@ -608,7 +609,7 @@ drawText(AbacusWidget w, TextType textType)
 			break;
 		case QUERY:
 			w->abacusDemo.query = True;
-			temp = queryText[line];
+			temp = lessonText[line];
 #ifdef DEBUG
 			(void) fprintf(stderr, " QUERY: %s\n", temp);
 #endif
@@ -672,7 +673,7 @@ doLesson(AbacusWidget w)
 	/* A '0' in demo number signifies that only the text is to be
 	 * displayed (i.e. nothing is to be added or subtracted).
 	 */
-	if (w->abacusDemo.moveCount <= numberMoves) {
+	if (w->abacusDemo.moveCount < numberMoves) {
 		setAbacusMove(w, ACTION_MOVE, w->abacusDemo.aux,
 			w->abacusDemo.deck, w->abacusDemo.rail,
 			w->abacusDemo.number);
@@ -701,6 +702,14 @@ doLesson(AbacusWidget w)
 	(void) fprintf(stderr, " doLesson:\n");
 #endif
 	if (++w->abacusDemo.moveCount > numberMoves) {
+		if (w->abacusDemo.highlightAux >= 0 &&
+				w->abacusDemo.highlightRail >= 0) {
+			setAbacusHighlightRail(w, ACTION_UNHIGHLIGHT_RAIL,
+				w->abacusDemo.highlightAux,
+				w->abacusDemo.highlightRail);
+			w->abacusDemo.highlightAux = -1;
+			w->abacusDemo.highlightRail = -1;
+		}
 		/*(void) fclose(w->abacusDemo.fp);*/
 		drawText(w, CONCL);
 		Sleep(2000);
@@ -934,7 +943,7 @@ setValuesAbacusDemo(Widget current, Widget request, Widget renew)
 		w->abacus.deck = IGNORE_DECK;
 		queryDemo(w, True);
 		break;
-	case REPEAT_DECK:
+	case ENTER_DECK:
 		w->abacus.deck = IGNORE_DECK;
 		queryDemo(w, False);
 		break;
@@ -1130,7 +1139,7 @@ showNextAbacusDemo(AbacusWidget w
 static
 #endif
 void
-showRepeatAbacusDemo(AbacusWidget w
+showEnterAbacusDemo(AbacusWidget w
 #ifndef WINVER
 , XEvent *event, char **args, int nArgs
 #endif
