@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusE.c
  *
- * Copyright 2017 - 2018  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 2017 - 2020  David A. Bagley, bagleyd AT verizon.net
  *
  * Abacus examples
  * All rights reserved.
@@ -271,7 +271,7 @@ codeCount(xmlNode *topNode)
 				char *tmp2;
 				int i;
 
-				(void) strncpy(tmp, (char *) value, valueLength);
+				(void) strcpy(tmp, (char *) value);
 				xmlFree(value);
 				trim(tmp);
 				tmp2 = tmp;
@@ -394,7 +394,7 @@ readMove(xmlNode *topNode, struct moveType *moveAbacus)
 			size_t valueLength = strlen((char *) value) + 1;
 			tmp = (char *) malloc(sizeof(char) *
 				valueLength);
-			(void) strncpy(tmp, (char *) value, valueLength);
+			(void) strcpy(tmp, (char *) value);
 			xmlFree(value);
 			if (debug) {
 				(void) printf("\t\t\t\t\t%s\n", node->name);
